@@ -8,8 +8,7 @@ from subprocess import CalledProcessError
 from subprocess import PIPE
 from subprocess import Popen
 
-import psutil
-
+from monasca_agent.common.psutil_wrapper import psutil
 from monasca_setup import agent_config
 
 log = logging.getLogger(__name__)
@@ -35,12 +34,14 @@ except AttributeError:
 
 
 def find_process_cmdline(search_string):
-    """Simple function to search running process for one with cmdline containing.
+    """Simple function to search running process for one with cmdline
+    containing search_string.
     """
     for process in psutil.process_iter():
         try:
-            if (search_string in ' '.join(process.cmdline()) and
-               'monasca-setup' not in ' '.join(process.cmdline())):
+            process_cmdline = ' '.join(process.as_dict()['cmdline'])
+            if (search_string in process_cmdline and
+               'monasca-setup' not in process_cmdline):
                 return process
         except psutil.NoSuchProcess:
             continue
@@ -53,7 +54,7 @@ def find_process_name(pname):
     """
     for process in psutil.process_iter():
         try:
-            if pname == process.name():
+            if pname == process.as_dict()['name']:
                 return process
         except psutil.NoSuchProcess:
             continue
@@ -73,11 +74,23 @@ def find_process_service(sname):
     return False
 
 
-def find_addr_listening_on_port(port):
+def find_addrs_listening_on_port(port, kind='inet'):
+    """Return the list of IP addresses which are listening
+    on the specified port.
+    """
+    listening = []
+    for connection in psutil.net_connections(kind):
+        if (connection.status == psutil.CONN_LISTEN and
+                connection.laddr[1] == int(port)):
+            listening.append(connection.laddr[0])
+    return listening
+
+
+def find_addr_listening_on_port_over_tcp(port):
     """Return the IP address which is listening on the specified TCP port."""
-    for conn in psutil.net_connections(kind='tcp'):
-        if conn.laddr[1] == port and conn.status == psutil.CONN_LISTEN:
-            return conn.laddr[0].lstrip("::ffff:")
+    ip = find_addrs_listening_on_port(port, 'tcp')
+    if ip:
+        return ip[0].lstrip("::ffff:")
 
 
 def watch_process(search_strings, service=None, component=None,
